==> qtjambi-webenginecore-debuginfo-windows-x64-6.5.5.jar: sources/QtJambiWebEngineCore/QWebEngineLoadingInfo_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineCore/qwebengineloadinginfo.h>
#include <QtCore/QVariant>
#include <QtCore/qurl.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QWebEngineLoadingInfo(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWebEngineLoadingInfo")
    QWebEngineLoadingInfo *_ptr = reinterpret_cast<QWebEngineLoadingInfo *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QWebEngineLoadingInfo(QWebEngineLoadingInfo)
void __qt_construct_QWebEngineLoadingInfo_cref_QWebEngineLoadingInfo(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebEngineLoadingInfo(QWebEngineLoadingInfo)")
    jobject other0 = __java_arguments[0].l;
    const QWebEngineLoadingInfo& __qt_other0 = qtjambi_cast<const QWebEngineLoadingInfo& >(__jni_env, other0);
    QWebEngineLoadingInfo *__qt_this = new(__qtjambi_ptr) QWebEngineLoadingInfo(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QWebEngineLoadingInfo::QWebEngineLoadingInfo(QWebEngineLoadingInfo)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineLoadingInfo_initialize_1native__Lio_qt_webengine_core_QWebEngineLoadingInfo_2Lio_qt_webengine_core_QWebEngineLoadingInfo_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebEngineLoadingInfo::QWebEngineLoadingInfo(QWebEngineLoadingInfo)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebEngineLoadingInfo_cref_QWebEngineLoadingInfo, sizeof(QWebEngineLoadingInfo), typeid(QWebEngineLoadingInfo), false, &deleter_QWebEngineLoadingInfo, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QWebEngineLoadingInfo
void __qt_destruct_QWebEngineLoadingInfo(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWebEngineLoadingInfo")
    reinterpret_cast<QWebEngineLoadingInfo*>(ptr)->~QWebEngineLoadingInfo();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineLoadingInfo::errorCode()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineLoadingInfo_errorCode_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineLoadingInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineLoadingInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineLoadingInfo::errorCode()const", __qt_this)
        __java_return_value = __qt_this->errorCode();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineLoadingInfo::errorDomain()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineLoadingInfo_errorDomain_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineLoadingInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineLoadingInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineLoadingInfo::errorDomain()const", __qt_this)
        QWebEngineLoadingInfo::ErrorDomain __qt_return_value = __qt_this->errorDomain();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineLoadingInfo::errorString()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineLoadingInfo_errorString_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineLoadingInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineLoadingInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineLoadingInfo::errorString()const", __qt_this)
        QString __qt_return_value = __qt_this->errorString();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineLoadingInfo::isErrorPage()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineLoadingInfo_isErrorPage_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineLoadingInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineLoadingInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineLoadingInfo::isErrorPage()const", __qt_this)
        __java_return_value = __qt_this->isErrorPage();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineLoadingInfo::operator=(QWebEngineLoadingInfo)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineLoadingInfo_assign_1native_1cref_1QWebEngineLoadingInfo__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineLoadingInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineLoadingInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineLoadingInfo::operator=(QWebEngineLoadingInfo)", __qt_this)
        const QWebEngineLoadingInfo& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QWebEngineLoadingInfo>(__jni_env, other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineLoadingInfo::status()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineLoadingInfo_status_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineLoadingInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineLoadingInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineLoadingInfo::status()const", __qt_this)
        QWebEngineLoadingInfo::LoadStatus __qt_return_value = __qt_this->status();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineLoadingInfo::url()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineLoadingInfo_url_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineLoadingInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineLoadingInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineLoadingInfo::url()const", __qt_this)
        QUrl __qt_return_value = __qt_this->url();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineLoadingInfo_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWebEngineLoadingInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineLoadingInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QWebEngineLoadingInfo(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWebEngineLoadingInfo(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QWebEngineLoadingInfo>("QWebEngineLoadingInfo", "io/qt/webengine/core/QWebEngineLoadingInfo");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWebEngineLoadingInfo, {
        ConstructorInfo(&__qt_construct_QWebEngineLoadingInfo_cref_QWebEngineLoadingInfo, "Lio/qt/webengine/core/QWebEngineLoadingInfo;")
    });
// END: function table

    registerMetaObject(typeId, QWebEngineLoadingInfo::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWebEngineLoadingInfo);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QWebEngineLoadingInfo::ErrorDomain>("QWebEngineLoadingInfo::ErrorDomain", "io/qt/webengine/core/QWebEngineLoadingInfo$ErrorDomain");
    registerEnumTypeInfo<QWebEngineLoadingInfo::LoadStatus>("QWebEngineLoadingInfo::LoadStatus", "io/qt/webengine/core/QWebEngineLoadingInfo$LoadStatus");
// END: enums and flags
}

==> qtjambi-webenginecore-debuginfo-windows-x64-6.6.1.jar: sources/QtJambiWebEngineCore/QWebEngineLoadingInfo_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineCore/qwebengineloadinginfo.h>
#include <QtCore/QMultiMap>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qurl.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QWebEngineLoadingInfo(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWebEngineLoadingInfo")
    QWebEngineLoadingInfo *_ptr = reinterpret_cast<QWebEngineLoadingInfo *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QWebEngineLoadingInfo(QWebEngineLoadingInfo)
void __qt_construct_QWebEngineLoadingInfo_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebEngineLoadingInfo(QWebEngineLoadingInfo)")
    jobject other0 = __java_arguments[0].l;
    const QWebEngineLoadingInfo& __qt_other0 = qtjambi_cast<const QWebEngineLoadingInfo& >(__jni_env, other0);
    QWebEngineLoadingInfo *__qt_this = new(__qtjambi_ptr) QWebEngineLoadingInfo(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QWebEngineLoadingInfo
void __qt_destruct_QWebEngineLoadingInfo(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWebEngineLoadingInfo")
    reinterpret_cast<QWebEngineLoadingInfo*>(ptr)->~QWebEngineLoadingInfo();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineLoadingInfo::QWebEngineLoadingInfo(QWebEngineLoadingInfo)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineLoadingInfo_initialize_1native__Lio_qt_webengine_core_QWebEngineLoadingInfo_2Lio_qt_webengine_core_QWebEngineLoadingInfo_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebEngineLoadingInfo::QWebEngineLoadingInfo(QWebEngineLoadingInfo)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebEngineLoadingInfo_0, sizeof(QWebEngineLoadingInfo), typeid(QWebEngineLoadingInfo), false, &deleter_QWebEngineLoadingInfo, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineLoadingInfo::errorCode()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineLoadingInfo_errorCode_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineLoadingInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineLoadingInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineLoadingInfo::errorCode()const", __qt_this)
        __java_return_value = __qt_this->errorCode();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineLoadingInfo::errorDomain()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineLoadingInfo_errorDomain_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineLoadingInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineLoadingInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineLoadingInfo::errorDomain()const", __qt_this)
        QWebEngineLoadingInfo::ErrorDomain __qt_return_value = __qt_this->errorDomain();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineLoadingInfo::errorString()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineLoadingInfo_errorString_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineLoadingInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineLoadingInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineLoadingInfo::errorString()const", __qt_this)
        QString __qt_return_value = __qt_this->errorString();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineLoadingInfo::isErrorPage()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineLoadingInfo_isErrorPage_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineLoadingInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineLoadingInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineLoadingInfo::isErrorPage()const", __qt_this)
        __java_return_value = __qt_this->isErrorPage();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineLoadingInfo::operator=(QWebEngineLoadingInfo)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineLoadingInfo_assign_1native_1cref_1QWebEngineLoadingInfo__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineLoadingInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineLoadingInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineLoadingInfo::operator=(QWebEngineLoadingInfo)", __qt_this)
        const QWebEngineLoadingInfo& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QWebEngineLoadingInfo>(__jni_env, other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineLoadingInfo::responseHeaders()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineLoadingInfo_responseHeaders_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineLoadingInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineLoadingInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineLoadingInfo::responseHeaders()const", __qt_this)
        QMultiMap<QByteArray, QByteArray> __qt_return_value = __qt_this->responseHeaders();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineLoadingInfo::status()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineLoadingInfo_status_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineLoadingInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineLoadingInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineLoadingInfo::status()const", __qt_this)
        QWebEngineLoadingInfo::LoadStatus __qt_return_value = __qt_this->status();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineLoadingInfo::url()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineLoadingInfo_url_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineLoadingInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineLoadingInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineLoadingInfo::url()const", __qt_this)
        QUrl __qt_return_value = __qt_this->url();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineLoadingInfo_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWebEngineLoadingInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineLoadingInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QWebEngineLoadingInfo(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWebEngineLoadingInfo(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QWebEngineLoadingInfo>("QWebEngineLoadingInfo", "io/qt/webengine/core/QWebEngineLoadingInfo");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWebEngineLoadingInfo, {
        ConstructorInfo(&__qt_construct_QWebEngineLoadingInfo_0, "Lio/qt/webengine/core/QWebEngineLoadingInfo;")
    });
// END: function table

    registerMetaObject(typeId, QWebEngineLoadingInfo::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWebEngineLoadingInfo);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QWebEngineLoadingInfo::ErrorDomain>("QWebEngineLoadingInfo::ErrorDomain", "io/qt/webengine/core/QWebEngineLoadingInfo$ErrorDomain");
    registerEnumTypeInfo<QWebEngineLoadingInfo::LoadStatus>("QWebEngineLoadingInfo::LoadStatus", "io/qt/webengine/core/QWebEngineLoadingInfo$LoadStatus");
// END: enums and flags
}
